@@ -1,6 +1,6 @@
 #!/bin/sh
 
-#    Copyright 2008-2014 Canonical Ltd.
+#    Copyright 2008-2016 Canonical Ltd.
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License version 3,
@@ -55,6 +55,7 @@ CUR=`pwd`
 export TESTPATH="$testdir/testarea"
 export TESTTMP="$testdir/testarea/tmp"
 export TESTSTATE="$TESTPATH/lib/ufw"
+export TESTCONFIG="$TESTPATH/etc/ufw"
 
 STOPONFAIL="no"
 STOPONSKIP="no"
@@ -156,6 +157,7 @@ done
 # clean up before functional tests
 rm -f "$CUR/src/*.pyc"
 rm -rf "$CUR/src/__pycache__"
+make clean
 
 # Functional tests
 echo "= Functional Tests ="
