@@ -1,6 +1,6 @@
 '''backend.py: interface for ufw backends'''
 #
-# Copyright 2008-2012 Canonical Ltd.
+# Copyright 2008-2018 Canonical Ltd.
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License version 3,
@@ -17,57 +17,70 @@
 
 import errno
 import os
+import pwd
 import re
 import stat
 import sys
 import ufw.util
-from ufw.util import warn, debug
-from ufw.common import UFWError, config_dir, iptables_dir, UFWRule
+from ufw.util import error, warn, debug, _findpath
+from ufw.common import UFWError, UFWRule
 import ufw.applications
 
+
 class UFWBackend:
     '''Interface for backends'''
-    def __init__(self, name, dryrun, extra_files=None):
+    def __init__(self, name, dryrun, extra_files=None,
+                 rootdir=None, datadir=None):
         self.defaults = None
         self.name = name
         self.dryrun = dryrun
         self.rules = []
         self.rules6 = []
 
-        self.files = {'defaults': os.path.join(config_dir, 'default/ufw'),
-                      'conf': os.path.join(config_dir, 'ufw/ufw.conf'),
-                      'apps': os.path.join(config_dir, 'ufw/applications.d') }
-        if extra_files != None:
+        p = _findpath(ufw.common.config_dir, datadir)
+        self.files = {'defaults': os.path.join(p, 'default/ufw'),
+                      'conf': os.path.join(p, 'ufw/ufw.conf'),
+                      'apps': os.path.join(p, 'ufw/applications.d') }
+        if extra_files is not None:
             self.files.update(extra_files)
 
-        self.loglevels = {'off':       0,
-                          'low':     100,
-                          'medium':  200,
-                          'high':    300,
-                          'full':    400 }
+        self.loglevels = {'off': 0,
+                          'low': 100,
+                          'medium': 200,
+                          'high': 300,
+                          'full': 400 }
 
-        self.do_checks = True
-        try:
-            self._do_checks()
-            self._get_defaults()
-            self._read_rules()
-        except Exception:
-            raise
+        self.do_checks = ufw.common.do_checks
+        self._do_checks()
+        self._get_defaults()
+        self._read_rules()
 
         self.profiles = ufw.applications.get_profiles(self.files['apps'])
 
-        self.iptables = os.path.join(iptables_dir, "iptables")
-        self.iptables_restore = os.path.join(iptables_dir, "iptables-restore")
-        self.ip6tables = os.path.join(iptables_dir, "ip6tables")
-        self.ip6tables_restore = os.path.join(iptables_dir, \
+        self.iptables = os.path.join(ufw.common.iptables_dir, "iptables")
+        self.iptables_restore = os.path.join(ufw.common.iptables_dir, \
+                                             "iptables-restore")
+        self.ip6tables = os.path.join(ufw.common.iptables_dir, "ip6tables")
+        self.ip6tables_restore = os.path.join(ufw.common.iptables_dir, \
                                               "ip6tables-restore")
 
         try:
             self.iptables_version = ufw.util.get_iptables_version(self.iptables)
-        except OSError:
+        except OSError: # pragma: no coverage
             err_msg = _("Couldn't determine iptables version")
             raise UFWError(err_msg)
 
+        # Initialize via initcaps only when we need it (LP: #1044361)
+        self.caps = None
+
+    def initcaps(self):
+        '''Initialize the capabilities database. This needs to be called
+           before accessing the database.'''
+
+        # Only initialize if not initialized already
+        if self.caps is not None:
+            return
+
         self.caps = {}
         self.caps['limit'] = {}
 
@@ -76,20 +89,33 @@ class UFWBackend:
         self.caps['limit']['6'] = False # historical default for the testsuite
 
         # Try to get capabilities from the running system if root
-        if self.do_checks and os.getuid() == 0 and not self.dryrun:
+        if self.do_checks and os.getuid() == 0 and not self.dryrun: # pragma: no coverage
             # v4
-            nf_caps = ufw.util.get_netfilter_capabilities(self.iptables)
+            try:
+                nf_caps = ufw.util.get_netfilter_capabilities(self.iptables)
+            except OSError as e:
+                msg = "initcaps\n%s" % e
+                if self.is_enabled():
+                    error(msg)
+                warn(msg)
+                return
+
             if 'recent-set' in nf_caps and 'recent-update' in nf_caps:
                 self.caps['limit']['4'] = True
             else:
                 self.caps['limit']['4'] = False
 
-            # v6
-            nf_caps = ufw.util.get_netfilter_capabilities(self.ip6tables)
-            if 'recent-set' in nf_caps and 'recent-update' in nf_caps:
-                self.caps['limit']['6'] = True
-            else:
-                self.caps['limit']['6'] = False
+            # v6 (skip capabilities check for ipv6 if ipv6 is disabled in ufw
+            # because the system may not have ipv6 support (LP: #1039729)
+            if self.use_ipv6():
+                try:
+                    nf_caps = ufw.util.get_netfilter_capabilities(self.ip6tables)
+                except OSError as e:
+                    error("initcaps\n%s" % e)
+                if 'recent-set' in nf_caps and 'recent-update' in nf_caps:
+                    self.caps['limit']['6'] = True
+                else:
+                    self.caps['limit']['6'] = False
 
     def is_enabled(self):
         '''Is firewall configured as enabled'''
@@ -106,7 +132,7 @@ class UFWBackend:
             return True
         return False
 
-    def _get_default_policy(self, primary="input"):
+    def _get_default_policy(self, primary="input", check_forward=False):
         '''Get default policy for specified primary chain'''
         policy = "default_" + primary + "_policy"
 
@@ -118,9 +144,33 @@ class UFWBackend:
         else:
             rstr = "deny"
 
+        if check_forward and primary == "forward":
+            enabled = False
+            err_msg = _("problem running sysctl")
+
+            (rc, out) = ufw.util.cmd(['sysctl', 'net.ipv4.ip_forward'])
+            if rc != 0: # pragma: no cover
+                raise UFWError(err_msg)
+            if '1' in out:
+                enabled = True
+
+            # IPv6 may be disabled, so ignore sysctl output
+            if self.use_ipv6():
+                (rc, out) = ufw.util.cmd(['sysctl', 'net.ipv6.conf.default.forwarding'])
+                if rc == 0 and '1' in out:
+                    enabled = True
+
+                (rc, out) = ufw.util.cmd(['sysctl', 'net.ipv6.conf.all.forwarding'])
+                if rc == 0 and '1' in out:
+                    enabled = True
+
+            if not enabled:
+                rstr = "disabled"
+
         return rstr
 
-    def _do_checks(self):
+    # Don't do coverage on this cause we don't run the unit tests as root
+    def _do_checks(self): # pragma: no coverage
         '''Perform basic security checks:
         is setuid or setgid (for non-Linux systems)
         checks that script is owned by root
@@ -146,8 +196,8 @@ class UFWBackend:
         if os.getgid() != os.getegid():
             err_msg = _("ERROR: this script should not be SGID")
             raise UFWError(err_msg)
-        uid = os.getuid()
 
+        uid = os.getuid()
         if uid != 0:
             err_msg = _("You need to be root to run this script")
             raise UFWError(err_msg)
@@ -187,7 +237,19 @@ class UFWBackend:
                 except Exception:
                     raise
 
-                if statinfo.st_uid != 0 and path not in warned_owner:
+                # snaps and clicks unpack to this, so handle it
+                click_user = 'clickpkg'
+                snap_user = 'snappypkg'
+                is_unpack_user = False
+                try:
+                    if pwd.getpwuid(statinfo.st_uid)[0] == click_user or \
+                            pwd.getpwuid(statinfo.st_uid)[0] == snap_user:
+                        is_unpack_user = True
+                except KeyError:
+                    pass
+
+                if statinfo.st_uid != 0 and not is_unpack_user and \
+                        path not in warned_owner:
                     warn_msg = _("uid is %(uid)s but '%(path)s' is owned by " \
                                  "%(st_uid)s") % ({'uid': str(uid), \
                                                'path': path, \
@@ -198,7 +260,8 @@ class UFWBackend:
                     warn_msg = _("%s is world writable!") % (path)
                     warn(warn_msg)
                     warned_world_write[path] = True
-                if mode & stat.S_IWGRP and path not in warned_group_write:
+                if mode & stat.S_IWGRP and path not in warned_group_write and \
+                        statinfo.st_gid != 0:
                     warn_msg = _("%s is group writable!") % (path)
                     warn(warn_msg)
                     warned_group_write[path] = True
@@ -225,7 +288,7 @@ class UFWBackend:
         for f in [self.files['defaults'], self.files['conf']]:
             try:
                 orig = ufw.util.open_file_read(f)
-            except Exception:
+            except Exception: # pragma: no coverage
                 err_msg = _("Couldn't open '%s' for reading") % (f)
                 raise UFWError(err_msg)
             pat = re.compile(r'^\w+="?\w+"?')
@@ -260,10 +323,7 @@ class UFWBackend:
             err_msg = _("'%s' is not writable" % (fn))
             raise UFWError(err_msg)
 
-        try:
-            fns = ufw.util.open_files(fn)
-        except Exception:
-            raise
+        fns = ufw.util.open_files(fn)
         fd = fns['tmp']
 
         found = False
@@ -281,7 +341,7 @@ class UFWBackend:
 
         try:
             ufw.util.close_files(fns)
-        except Exception:
+        except Exception: # pragma: no coverage
             raise
 
         # Now that the files are written out, update value in memory
@@ -291,33 +351,21 @@ class UFWBackend:
         '''Sets default application policy of firewall'''
         if not self.dryrun:
             if policy == "allow":
-                try:
-                    self.set_default(self.files['defaults'], \
-                                            "DEFAULT_APPLICATION_POLICY", \
-                                            "\"ACCEPT\"")
-                except Exception:
-                    raise
+                self.set_default(self.files['defaults'], \
+                                        "DEFAULT_APPLICATION_POLICY", \
+                                        "\"ACCEPT\"")
             elif policy == "deny":
-                try:
-                    self.set_default(self.files['defaults'], \
-                                            "DEFAULT_APPLICATION_POLICY", \
-                                            "\"DROP\"")
-                except Exception:
-                    raise
+                self.set_default(self.files['defaults'], \
+                                        "DEFAULT_APPLICATION_POLICY", \
+                                        "\"DROP\"")
             elif policy == "reject":
-                try:
-                    self.set_default(self.files['defaults'], \
-                                            "DEFAULT_APPLICATION_POLICY", \
-                                            "\"REJECT\"")
-                except Exception:
-                    raise
+                self.set_default(self.files['defaults'], \
+                                        "DEFAULT_APPLICATION_POLICY", \
+                                        "\"REJECT\"")
             elif policy == "skip":
-                try:
-                    self.set_default(self.files['defaults'], \
-                                            "DEFAULT_APPLICATION_POLICY", \
-                                            "\"SKIP\"")
-                except Exception:
-                    raise
+                self.set_default(self.files['defaults'], \
+                                        "DEFAULT_APPLICATION_POLICY", \
+                                        "\"SKIP\"")
             else:
                 err_msg = _("Unsupported policy '%s'") % (policy)
                 raise UFWError(err_msg)
@@ -338,12 +386,9 @@ class UFWBackend:
                 tmp = template.dup_rule()
                 tmp.dapp = ""
                 tmp.set_port("any", "src")
-                try:
-                    (port, proto) = ufw.util.parse_port_proto(i)
-                    tmp.set_protocol(proto)
-                    tmp.set_port(port, "dst")
-                except Exception:
-                    raise
+                (port, proto) = ufw.util.parse_port_proto(i)
+                tmp.set_protocol(proto)
+                tmp.set_port(port, "dst")
 
                 tmp.dapp = template.dapp
 
@@ -351,12 +396,9 @@ class UFWBackend:
                     # Just use the same ports as dst for src when they are the
                     # same to avoid duplicate rules
                     tmp.sapp = ""
-                    try:
-                        (port, proto) = ufw.util.parse_port_proto(i)
-                        tmp.set_protocol(proto)
-                        tmp.set_port(port, "src")
-                    except Exception:
-                        raise
+                    (port, proto) = ufw.util.parse_port_proto(i)
+                    tmp.set_protocol(proto)
+                    tmp.set_port(port, "src")
 
                     tmp.sapp = template.sapp
                     rules.append(tmp)
@@ -364,12 +406,9 @@ class UFWBackend:
                     for j in sports:
                         rule = tmp.dup_rule()
                         rule.sapp = ""
-                        try:
-                            (port, proto) = ufw.util.parse_port_proto(j)
-                            rule.set_protocol(proto)
-                            rule.set_port(port, "src")
-                        except Exception:
-                            raise
+                        (port, proto) = ufw.util.parse_port_proto(j)
+                        rule.set_protocol(proto)
+                        rule.set_port(port, "src")
 
                         if rule.protocol == "any":
                             rule.set_protocol(tmp.protocol)
@@ -380,12 +419,9 @@ class UFWBackend:
             for p in ufw.applications.get_ports(self.profiles[template.sport]):
                 rule = template.dup_rule()
                 rule.sapp = ""
-                try:
-                    (port, proto) = ufw.util.parse_port_proto(p)
-                    rule.set_protocol(proto)
-                    rule.set_port(port, "src")
-                except Exception:
-                    raise
+                (port, proto) = ufw.util.parse_port_proto(p)
+                rule.set_protocol(proto)
+                rule.set_port(port, "src")
 
                 rule.sapp = template.sapp
                 rules.append(rule)
@@ -393,12 +429,9 @@ class UFWBackend:
             for p in ufw.applications.get_ports(self.profiles[template.dport]):
                 rule = template.dup_rule()
                 rule.dapp = ""
-                try:
-                    (port, proto) = ufw.util.parse_port_proto(p)
-                    rule.set_protocol(proto)
-                    rule.set_port(port, "dst")
-                except Exception:
-                    raise
+                (port, proto) = ufw.util.parse_port_proto(p)
+                rule.set_protocol(proto)
+                rule.set_port(port, "dst")
 
                 rule.dapp = template.dapp
                 rules.append(rule)
@@ -439,11 +472,8 @@ class UFWBackend:
                         template.set_port(template.dapp, "dst")
                     if template.sapp != "":
                         template.set_port(template.sapp, "src")
-                    try:
-                        new_app_rules = self.get_app_rules_from_template(\
+                    new_app_rules = self.get_app_rules_from_template(\
                                           template)
-                    except Exception:
-                        raise
 
                     for new_r in new_app_rules:
                         new_r.normalize()
@@ -468,7 +498,7 @@ class UFWBackend:
             try:
                 self._write_rules(False) # ipv4
                 self._write_rules(True) # ipv6
-            except Exception:
+            except Exception: # pragma: no coverage
                 err_msg = _("Couldn't update application rules")
                 raise UFWError(err_msg)
 
@@ -493,13 +523,15 @@ class UFWBackend:
         elif matches > 1:
             err_msg = _("Found multiple matches for '%s'. Please use exact profile name") % \
                         (profile_name)
-        err_msg = _("Could not find a profile matching '%s'") % (profile_name)
+        else:
+            err_msg = _("Could not find a profile matching '%s'") % \
+                        (profile_name)
         raise UFWError(err_msg)
 
     def find_other_position(self, position, v6):
         '''Return the absolute position in the other list of the rule with the
-	   user position of the given list. For example, find_other_position(4,
-	   True) will return the absolute position of the rule in the ipv4 list
+           user position of the given list. For example, find_other_position(4,
+           True) will return the absolute position of the rule in the ipv4 list
            matching the user specified '4' rule in the ipv6 list.
         '''
         # Invalid search (v6 rule with too low position)
@@ -586,11 +618,8 @@ class UFWBackend:
             else:
                 new_level = self.defaults['loglevel']
 
-        try:
-            self.set_default(self.files['conf'], "LOGLEVEL", new_level)
-            self.update_logging(new_level)
-        except Exception:
-            raise
+        self.set_default(self.files['conf'], "LOGLEVEL", new_level)
+        self.update_logging(new_level)
 
         if new_level == "off":
             return _("Logging disabled")
@@ -661,39 +690,39 @@ class UFWBackend:
         return matched
 
     # API overrides
-    def set_default_policy(self, policy, direction):
+    def set_default_policy(self, policy, direction): # pragma: no coverage
         '''Set default policy for specified direction'''
         raise UFWError("UFWBackend.set_default_policy: need to override")
 
-    def get_running_raw(self, rules_type):
+    def get_running_raw(self, rules_type): # pragma: no coverage
         '''Get status of running firewall'''
         raise UFWError("UFWBackend.get_running_raw: need to override")
 
-    def get_status(self, verbose, show_count):
+    def get_status(self, verbose, show_count): # pragma: no coverage
         '''Get managed rules'''
         raise UFWError("UFWBackend.get_status: need to override")
 
-    def set_rule(self, rule, allow_reload):
+    def set_rule(self, rule, allow_reload): # pragma: no coverage
         '''Update firewall with rule'''
         raise UFWError("UFWBackend.set_rule: need to override")
 
-    def start_firewall(self):
+    def start_firewall(self): # pragma: no coverage
         '''Start the firewall'''
         raise UFWError("UFWBackend.start_firewall: need to override")
 
-    def stop_firewall(self):
+    def stop_firewall(self): # pragma: no coverage
         '''Stop the firewall'''
         raise UFWError("UFWBackend.stop_firewall: need to override")
 
-    def get_app_rules_from_system(self, template, v6):
+    def get_app_rules_from_system(self, template, v6): # pragma: no coverage
         '''Get a list if rules based on template'''
         raise UFWError("UFWBackend.get_app_rules_from_system: need to " + \
                        "override")
 
-    def update_logging(self, level):
+    def update_logging(self, level): # pragma: no coverage
         '''Update loglevel of running firewall'''
         raise UFWError("UFWBackend.update_logging: need to override")
 
-    def reset(self):
+    def reset(self): # pragma: no coverage
         '''Reset the firewall'''
         raise UFWError("UFWBackend.reset: need to override")
