@@ -1,6 +1,6 @@
 '''common.py: common classes for ufw'''
 #
-# Copyright 2008-2016 Canonical Ltd.
+# Copyright 2008-2018 Canonical Ltd.
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License version 3,
@@ -29,6 +29,7 @@ prefix_dir = "#PREFIX#"
 iptables_dir = "#IPTABLES_DIR#"
 do_checks = True
 
+
 class UFWError(Exception):
     '''This class represents ufw exceptions'''
     def __init__(self, value):
@@ -293,22 +294,47 @@ class UFWRule:
 
     def set_interface(self, if_type, name):
         '''Sets an interface for rule'''
+        # libxtables/xtables.c xtables_parse_interface() specifies
+        # - < 16
+        # - not empty
+        # - doesn't contain ' '
+        # - doesn't contain '/'
+        #
+        # net/core/dev.c from the kernel specifies:
+        # - < 16
+        # - not empty
+        # - != '.' or '..'
+        # - doesn't contain '/', ':' or whitespace
         if if_type != "in" and if_type != "out":
             err_msg = _("Bad interface type")
             raise UFWError(err_msg)
 
+        # Separate a few of the invalid checks out so we can give a nice error
         if '!' in str(name):
             err_msg = _("Bad interface name: reserved character: '!'")
             raise UFWError(err_msg)
 
-        if not re.match(r'^[a-zA-Z][a-zA-Z0-9:]*[a-zA-Z0-9]', str(name)):
-            err_msg = _("Bad interface name")
-            raise UFWError(err_msg)
-
         if ':' in str(name):
             err_msg = _("Bad interface name: can't use interface aliases")
             raise UFWError(err_msg)
 
+        if str(name) == "." or str(name) == "..":
+            err_msg = _("Bad interface name: can't use '.' or '..'")
+            raise UFWError(err_msg)
+
+        if (len(str(name)) == 0):
+            err_msg = _("Bad interface name: interface name is empty")
+            raise UFWError(err_msg)
+
+        if (len(str(name)) > 15):
+            err_msg = _("Bad interface name: interface name too long")
+            raise UFWError(err_msg)
+
+        # We are going to limit this even further to avoid shell meta
+        if not re.match(r'^[a-zA-Z0-9_\-\.\+,=%@]+$', str(name)):
+            err_msg = _("Bad interface name")
+            raise UFWError(err_msg)
+
         if if_type == "in":
             self.interface_in = name
         else:
@@ -316,7 +342,10 @@ class UFWRule:
 
     def set_position(self, num):
         '''Sets the position of the rule'''
-        if not re.match(r'^[0-9]+', str(num)):
+        # -1 prepend
+        #  0 append
+        # >0 insert
+        if str(num) != "-1" and not re.match(r'^[0-9]+', str(num)):
             err_msg = _("Insert position '%s' is not a valid position") % (num)
             raise UFWError(err_msg)
         self.position = int(num)
@@ -450,7 +479,7 @@ class UFWRule:
 
     def fuzzy_dst_match(x, y):
         '''This will match if x is more specific than y. Eg, for protocol if x
-	   is tcp and y is all or for address if y is a network and x is a
+           is tcp and y is all or for address if y is a network and x is a
            subset of y (where x is either an address or network). Returns:
 
             0  match
@@ -508,11 +537,11 @@ class UFWRule:
             return 1
 
         if y.interface_in == "":
-	    # If destination interface is not specified, destination addresses
+            # If destination interface is not specified, destination addresses
             # must match or x must be contained in y
 
             if x.interface_in == "" and x._is_anywhere(x.dst):
-		# if x and y interfaces are not specified, and x.dst is
+                # if x and y interfaces are not specified, and x.dst is
                 # anywhere then ok
                 pass
             elif x.dst != y.dst and '/' not in y.dst:
@@ -524,10 +553,10 @@ class UFWRule:
                       (x.dst, y.dst))
                 return 1
         else:
-	    # If destination interface is specified, then:
+            # If destination interface is specified, then:
             #  if specified, both interfaces must match or
             #  the IP of the interface must match the IP of y or
-	    #  the IP of the interface must be contained in y
+            #  the IP of the interface must be contained in y
             if x.interface_in != "" and x.interface_in != y.interface_in:
                 debug("(interface) " + dbg_msg + " (%s != %s)" % \
                       (x.interface_in, y.interface_in))
