@@ -1,5 +1,5 @@
 #
-# Copyright 2012-2016 Canonical Ltd.
+# Copyright 2012-2018 Canonical Ltd.
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 3,
@@ -18,6 +18,7 @@ import unittest
 import tests.unit.support
 import ufw.common
 
+
 class CommonTestCase(unittest.TestCase):
     def setUp(self):
         self.rules = {
@@ -50,7 +51,7 @@ class CommonTestCase(unittest.TestCase):
                     dport="80,443,8080:8090", sport="23"),
                 "log":  ufw.common.UFWRule("allow", "tcp", dport="22"),
                 "log-all":  ufw.common.UFWRule("allow", "tcp", dport="22"),
-                }
+               }
         self.rules['dapp'].dapp = "Apache"
         self.rules['dapp'].dport = "80"
         self.rules['dapp'].proto = "tcp"
@@ -334,7 +335,9 @@ class CommonTestCase(unittest.TestCase):
         '''Test set_interface()'''
         r = self.rules["any"]
         for if_type in ["in", "out"]:
-            for interface in ["eth0", "wlan1", "br_lan"]:
+            for interface in ["eth0", "wlan1", "br_lan", "virbr0-nic", "0eth",
+                              "eth0_1", "eth0.1", "foo%bar", "foo@Bar",
+                              "=foo", "vethQNIAKF@if18", "lo"]:
                 r.set_interface(if_type, interface)
                 if if_type == "in":
                     self.assertEquals(interface, r.interface_in, "%s != %s" %
@@ -355,7 +358,8 @@ class CommonTestCase(unittest.TestCase):
                                                    interface)
 
         for if_type in ["in", "out"]:
-            for interface in ["\tfoo", "<$%", "0eth", "eth0:0", "!eth0"]:
+            for interface in ["\tfoo", "<bad", "also/bad", "eth0:0", "!eth0",
+                              "", ".", "..", "$foo", "`uname`", "a" * 16]:
                 tests.unit.support.check_for_exception(self,
                                                        ufw.common.UFWError,
                                                        r.set_interface,
@@ -666,6 +670,7 @@ class CommonTestCase(unittest.TestCase):
         tests.unit.support.check_for_exception(self, ValueError,
                                                x.fuzzy_dst_match,
                                                None)
+
     def test__is_anywhere(self):
         '''Test _is_anywhere()'''
         r = self.rules['any']
@@ -721,10 +726,12 @@ class CommonTestCase(unittest.TestCase):
         self.assertEquals(self.rules['sapp'].src, t[3])
         self.assertEquals("out_br_lan", t[4])
 
+
 def test_main(): # used by runner.py
     tests.unit.support.run_unittest(
             CommonTestCase
     )
 
+
 if __name__ == "__main__": # used when standalone
     unittest.main()
